WIP

# Python Prediction Markets
Lightweight Python wrapper that combines the trading API of various markets into one interface.

### Markets Currently Supported:
- [Kalshi](https://kalshi.com/)
- [Polymarket](https://polymarket.com/)

### Planned:
- [Manifold](https://manifold.markets/home)

# Usage

TODO